**Mimical (Modelling the Intensity of Multiply-Imaged Celestial Ancient Light)**


Mimical is an intensity modelling code for multiply-imaged objects, performing simultaenous Bayseian inference of model parameters via the nested sampling algorithm. Mimical supports any astropy model, and supports user defined parameter polynomial depenency with image wavelength.


.. image:: docs/mimical_workflow.pdf